#! Flux2D 11.2
import os

  
## Application
     
lastInstance = ApplicationMagneticTransient2D(domain2D=Domain2DPlane(lengthUnit=LengthUnit['MILLIMETER'],
                                              depth='44'),
                                              coilCoefficient=CoilCoefficientAutomatic(),
                                              transientInitialization=TransientInitializationZeroInitialSolution())
     
Application[2].transientInitialization = TransientInitializationStaticComputation()
     
     
     
## Creation of materials
     
lastInstance = Material(name='magnet',
                        propertyBH=PropertyBhMagnetOneDirection(br='.7',
                        mur='1.22'))
     
lastInstance = Material(name='mu_lin',
                        propertyBH=PropertyBhLinear(mur='5000'))
       
   
INSTALL = os.environ["INSTALLFLUX"] + "//.."
macroFile = INSTALL + "/Materials/FLUX_111_MATERI.DAT"
importMaterial(fileName=macroFile, materialNames=['FLU_1010_XC10+RO         :'])
importMaterial(fileName=macroFile, materialNames=['FLU_M800_50A         :'])     
     
## Mechanical sets
     
lastInstance = MechanicalSetRotation1Axis(name='rotor',
                                          kinematics=RotatingImposedSpeed(velocity='10000',
                                          initialPosition='0'),
                                          rotationAxis=RotationZAxis(coordSys=CoordSys['XY1'],
                                          pivot=['0',
                                          '0']))
     
lastInstance = MechanicalSetFixed(name='STATOR : STATOR')
     
## Import circuit
     
INSTALL = os.environ["INSTALLFLUX"] + "//.."
macroFile = INSTALL + "/Extensions/Macros/Macros_Flux_Circuit/Circuit_Collector_2D.PFM"
loadMacro(fileName=macroFile)
     
Circuit_Collector_2D(id='CO_',
                     NSlot=12,
                     Ncslot=2,
                     throw=3,
                     comPitch=1,
                     NBrush=4,
                     DCVoltage=11.5,
                     Resistance=1.0E-6,
                     Inductance=1.7E-6,
                     RCoil=0.012,
                     TetaBrush=29.0,
                     TetaBar=20.69,
                     RonBarBrush=1.0E-4,
                     TetaIni=0.0)
     
     
startMacroTransaction()
VariationParameter['CO_TETAINI'] = VariationParameterPilot(name='CO_TETAINI',
                                                           referenceValue=0.0)
endMacroTransaction()
     
     
VariationParameter['CO_RESIST_VAL'].formula = '1E-4'
     
     
VariationParameter['CO_DCVOLTAGE_VAL'].formula = '16'
     
     
## Define face regions properties             
startMacroTransaction()
RegionFace['INFINITE', 'MAGNET_1', 'MAGNET_2', 'MAGNET_3', 'MAGNET_4', 'STATOR_AIR'].mechanicalSet = MechanicalSet['STATOR']
     
RegionFace['INFINITE'].magneticTransient2D = MagneticTransient2DFaceVacuum()
     
RegionFace['MAGNET_1'].magneticTransient2D = MagneticTransient2DFaceVacuum()
     
RegionFace['MAGNET_2'].magneticTransient2D = MagneticTransient2DFaceVacuum()
     
RegionFace['MAGNET_3'].magneticTransient2D = MagneticTransient2DFaceVacuum()
     
RegionFace['MAGNET_4'].magneticTransient2D = MagneticTransient2DFaceVacuum()
     
RegionFace['STATOR_AIR'].magneticTransient2D = MagneticTransient2DFaceVacuum()
     
endMacroTransaction()
     
RegionFace['STATOR'].magneticTransient2D = MagneticTransient2DFaceMagnetic(material=Material['MU_LIN'])
     
     
startMacroTransaction()
RegionFace['PHASE_POS_1', 'PHASE_POS_2', 'PHASE_POS_3', 'PHASE_POS_4', 'PHASE_POS_5', 'PHASE_POS_6'].mechanicalSet = MechanicalSet['ROTOR']
     
RegionFace['PHASE_POS_1'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                     seriesParallel=AllInSeries(),
                                                                                     electricComponent=CoilConductor['CO_COIL_1P']))
     
RegionFace['PHASE_POS_2'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                     seriesParallel=AllInSeries(),
                                                                                     electricComponent=CoilConductor['CO_COIL_2P']))
     
RegionFace['PHASE_POS_3'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                     seriesParallel=AllInSeries(),
                                                                                     electricComponent=CoilConductor['CO_COIL_3P']))
     
RegionFace['PHASE_POS_4'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                     seriesParallel=AllInSeries(),
                                                                                     electricComponent=CoilConductor['CO_COIL_4P']))
     
RegionFace['PHASE_POS_5'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                     seriesParallel=AllInSeries(),
                                                                                     electricComponent=CoilConductor['CO_COIL_5P']))
     
RegionFace['PHASE_POS_6'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                     seriesParallel=AllInSeries(),
                                                                                     electricComponent=CoilConductor['CO_COIL_6P']))
     
endMacroTransaction()
     
startMacroTransaction()
RegionFace['PHASE_POS_7', 'PHASE_POS_8', 'PHASE_POS_9', 'PHASE_POS_10', 'PHASE_POS_11', 'PHASE_POS_12'].mechanicalSet = MechanicalSet['ROTOR']
     
RegionFace['PHASE_POS_7'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                     seriesParallel=AllInSeries(),
                                                                                     electricComponent=CoilConductor['CO_COIL_7P']))
     
RegionFace['PHASE_POS_8'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                     seriesParallel=AllInSeries(),
                                                                                     electricComponent=CoilConductor['CO_COIL_8P']))
     
RegionFace['PHASE_POS_9'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                     seriesParallel=AllInSeries(),
                                                                                     electricComponent=CoilConductor['CO_COIL_9P']))
     
RegionFace['PHASE_POS_10'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                      seriesParallel=AllInSeries(),
                                                                                      electricComponent=CoilConductor['CO_COIL_10P']))
     
RegionFace['PHASE_POS_11'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                      seriesParallel=AllInSeries(),
                                                                                      electricComponent=CoilConductor['CO_COIL_11P']))
     
RegionFace['PHASE_POS_12'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                      seriesParallel=AllInSeries(),
                                                                                      electricComponent=CoilConductor['CO_COIL_12P']))
     
endMacroTransaction()
     
startMacroTransaction()
RegionFace['PHASE_NEG_1', 'PHASE_NEG_2', 'PHASE_NEG_3', 'PHASE_NEG_4', 'PHASE_NEG_5', 'PHASE_NEG_6'].mechanicalSet = MechanicalSet['ROTOR']
     
RegionFace['PHASE_NEG_1'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                     seriesParallel=AllInSeries(),
                                                                                     electricComponent=CoilConductor['CO_COIL_1N']))
     
RegionFace['PHASE_NEG_2'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                     seriesParallel=AllInSeries(),
                                                                                     electricComponent=CoilConductor['CO_COIL_2N']))
     
RegionFace['PHASE_NEG_3'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                     seriesParallel=AllInSeries(),
                                                                                     electricComponent=CoilConductor['CO_COIL_3N']))
     
RegionFace['PHASE_NEG_4'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                     seriesParallel=AllInSeries(),
                                                                                     electricComponent=CoilConductor['CO_COIL_4N']))
     
RegionFace['PHASE_NEG_5'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                     seriesParallel=AllInSeries(),
                                                                                     electricComponent=CoilConductor['CO_COIL_5N']))
     
RegionFace['PHASE_NEG_6'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                     seriesParallel=AllInSeries(),
                                                                                     electricComponent=CoilConductor['CO_COIL_6N']))
     
endMacroTransaction()
     
startMacroTransaction()
RegionFace['PHASE_NEG_7'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                     seriesParallel=AllInSeries(),
                                                                                     electricComponent=CoilConductor['CO_COIL_7N']))
     
RegionFace['PHASE_NEG_8'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                     seriesParallel=AllInSeries(),
                                                                                     electricComponent=CoilConductor['CO_COIL_8N']))
     
RegionFace['PHASE_NEG_9'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                     seriesParallel=AllInSeries(),
                                                                                     electricComponent=CoilConductor['CO_COIL_9N']))
     
RegionFace['PHASE_NEG_10'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                      seriesParallel=AllInSeries(),
                                                                                      electricComponent=CoilConductor['CO_COIL_10N']))
     
RegionFace['PHASE_NEG_11'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                      seriesParallel=AllInSeries(),
                                                                                      electricComponent=CoilConductor['CO_COIL_11N']))
     
RegionFace['PHASE_NEG_12'].magneticTransient2D = MagneticTransient2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='7',
                                                                                      seriesParallel=AllInSeries(),
                                                                                      electricComponent=CoilConductor['CO_COIL_12N']))
     
endMacroTransaction()
     
RegionFace['PHASE_NEG_7', 'PHASE_NEG_8', 'PHASE_NEG_9', 'PHASE_NEG_10', 'PHASE_NEG_11', 'PHASE_NEG_12'].mechanicalSet = MechanicalSet['ROTOR']
     
     
startMacroTransaction()
RegionFace['ROTATING_AIRGAP'].magneticTransient2D = MagneticTransient2DFaceVacuum()
     
RegionFace['ROTATING_AIRGAP'].mechanicalSet = MechanicalSet['ROTOR']
     
endMacroTransaction()
     
RegionFace['ROTOR'].magneticTransient2D = MagneticTransient2DFaceMagnetic(material=Material['FLU_M800_50A'])
     
     
RegionFace['ROTOR_AIR'].magneticTransient2D = MagneticTransient2DFaceInactive()
     
     
RegionFace['SHAFT'].magneticTransient2D = MagneticTransient2DFaceMagnetic(material=Material['MU_LIN'])
     
     
startMacroTransaction()
RegionFace['WEDGE'].magneticTransient2D = MagneticTransient2DFaceVacuum()
     
RegionFace['WEDGE'].mechanicalSet = MechanicalSet['ROTOR']
     
endMacroTransaction()

     
RegionFace['ROTOR'].mechanicalSet = MechanicalSet['ROTOR']

RegionFace['SHAFT'].mechanicalSet = MechanicalSet['ROTOR']

RegionFace['STATOR'].mechanicalSet = MechanicalSet['STATOR']
     
     
startMacroTransaction()
RegionFace['STATOR'].magneticTransient2D = MagneticTransient2DFaceMagnetic(material=Material['FLU_1010_XC10+RO'])
     
RegionFace['SHAFT'].magneticTransient2D = MagneticTransient2DFaceMagnetic(material=Material['FLU_1010_XC10+RO'])
     
endMacroTransaction()
     
startMacroTransaction()
RegionFace['MAGNET_1'].magneticTransient2D = MagneticTransient2DFaceMagnetic(material=Material['MAGNET'])
     
RegionFace['MAGNET_2'].magneticTransient2D = MagneticTransient2DFaceMagnetic(material=Material['MAGNET'])
     
RegionFace['MAGNET_3'].magneticTransient2D = MagneticTransient2DFaceMagnetic(material=Material['MAGNET'])
     
RegionFace['MAGNET_4'].magneticTransient2D = MagneticTransient2DFaceMagnetic(material=Material['MAGNET'])
     
endMacroTransaction()
     
orientRegSurfMaterial(region=RegionFace['MAGNET_1'], coordSys=CoordSys['XY1'], orientation='Direction', angle='45')
orientRegSurfMaterial(region=RegionFace['MAGNET_2'], coordSys=CoordSys['XY1'], orientation='Direction', angle='45+90+180')
orientRegSurfMaterial(region=RegionFace['MAGNET_3'], coordSys=CoordSys['XY1'], orientation='Direction', angle='45+180')
orientRegSurfMaterial(region=RegionFace['MAGNET_4'], coordSys=CoordSys['XY1'], orientation='Direction', angle='45+270+180')

     
saveProjectAs('physbuilt.FLU')
     
        
     
